***********
Conventions
***********

Formatting conventions
----------------------
The following formatting conventions are used throughout this guide:

* *Italic* - Used for commands, filenames, directories, script variables, keywords, emphasis, technical terms, and Internet domain names
* *[section]/variable* - Variable *variable* of section *section* of configuration file
* *file:[section]/variable* - Variable *variable* of section *section* of configuration file *file*

Prompts
-------
Throughout documentation following prompts are used in examples:

Super-user in home directory::

    #

Super-user with current directory *dir*::

    root@dir#

User *user* with current directory *dir*::

    user@dir$

